.. _release_notes-name:

!!!!!!!!!!!!!
release_notes
!!!!!!!!!!!!!

.. meta::
  :keywords: release_notes,xrst,release,notes,by,year

.. index:: release_notes, xrst, release, notes, year

.. _release_notes-title:

xrst Release Notes By Year
##########################

:ref:`2024-name`,
:ref:`2023-name`,
:ref:`2022-name`,
:ref:`2021-name`

.. toctree::
  :maxdepth: 1
  :hidden:

  2024
  2023
  2022
  2021
